@@ -1,15 +1,14 @@
 package SHARYANTO::Proc::ChildError;
 BEGIN {
-  $SHARYANTO::Proc::ChildError::VERSION = '0.03';
+  $SHARYANTO::Proc::ChildError::VERSION = '0.04';
 }
-# ABSTRACT: Explain process child error
 
 use 5.010;
 require Exporter;
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(explain_child_error);
 
-# taken from perldoc -f system
+our $VERSION = '0.04'; # VERSION
 
 sub explain_child_error {
     my $e = shift // $?;
@@ -27,6 +26,8 @@ sub explain_child_error {
 }
 
 1;
+# ABSTRACT: Explain process child error
+
 
 __END__
 =pod
@@ -37,7 +38,18 @@ SHARYANTO::Proc::ChildError - Explain process child error
 
 =head1 VERSION
 
-version 0.03
+version 0.04
+
+=head1 FUNCTIONS
+
+=head2 explain_child_error(INT) => STR
+
+Taken from perldoc -f system. Converts error number to something like one of the
+following:
+
+ failed to execute: -1
+ died with signal 15, with coredump
+ exited with value 3
 
 =head1 AUTHOR
 
